changeset 79205:b68f875d7f68

(Fcurrent_idle_time): Doc fix.
author Richard M. Stallman <rms@gnu.org>
date Wed, 24 Oct 2007 08:23:01 +0000
parents 588d507a3ebf
children 2f9a621d6bd9
files src/keyboard.c
diffstat 1 files changed, 4 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/keyboard.c	Wed Oct 24 08:22:35 2007 +0000
+++ b/src/keyboard.c	Wed Oct 24 08:23:01 2007 +0000
@@ -4612,12 +4612,14 @@
 }
 
 DEFUN ("current-idle-time", Fcurrent_idle_time, Scurrent_idle_time, 0, 0, 0,
-       doc: /* Return the current length of Emacs idleness.
-The value is returned as a list of three integers.  The first has the
+       doc: /* Return the current length of Emacs idleness, or nil.
+The value when Emacs is idle is a list of three integers.  The first has the
 most significant 16 bits of the seconds, while the second has the
 least significant 16 bits.  The third integer gives the microsecond
 count.
 
+The value when Emacs is not idle is nil.
+
 The microsecond count is zero on systems that do not provide
 resolution finer than a second.  */)
   ()